/* Bluefish HTML Editor
 * wml.h - WML support dialogs
 *
 * Copyright (C) 1999,2000 Olivier Sessink, Roland Steinbach
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __WML_H_
#define __WML_H_

void general_wml_cb(GtkWidget * widget, gpointer data);
void carddialog_cb(GtkWidget * widget, gpointer data);
void postfielddialog_cb(GtkWidget * widget, gpointer data);
void vardialog_cb(GtkWidget * widget, gpointer data);
void godialog_cb(GtkWidget * widget, gpointer data);
void dodialog_cb(GtkWidget * widget, gpointer data);
void anchordialog_cb(GtkWidget * widget, gpointer data);
void accessdialog_cb(GtkWidget * widget, gpointer data);

#endif							/* __WML_H_ */
